/*
derived_anal.do

Created August 10 2002 by Jeffrey Kling
Last modified November 26 2003 by Jeffrey Kling
              January  30 2003 by Lisa Sanbonmatsu
              April     2,2004 by LS - added in log name/date/and restrictions

Creates a log files of between groups differences in outcomes and mediators
of MTO data, using methods outlined in analytic methods memo.

requires various parameters -- see domain_tables.do

program logic outlined in program derived_anal at end of this file

*/

version 7.0
clear
macro   drop _all


capture program drop store_est
program define store_est
 version 7.0
 local modl `1' 
 local i `2'
 local x `3'
 local es `4'

 if "`modl'"=="itt" {
  local ra ra_`es'_`i'
 }
 if "`modl'"=="tot" {
  local ra ra_`es'c1_`i'
 }
 if "`x'"=="nox" {
  local x
 }
 scalar `es'_`modl'`x'_`i'    = _b[`ra'] 
 scalar `es'_`modl'`x'_se_`i' = _se[`ra'] 
 scalar `es'_`modl'`x'_tp_`i' = (ttail(df_r,abs(`es'_`modl'`x'_`i')/`es'_`modl'`x'_se_`i'))*2
 scalar `es'_`modl'`x'_hi_`i' = (`es'_`modl'`x'_`i'+invnorm(.975)*`es'_`modl'`x'_se_`i' ) 
 scalar `es'_`modl'`x'_lo_`i' = (`es'_`modl'`x'_`i'-invnorm(.975)*`es'_`modl'`x'_se_`i' ) 
 global `es'_`modl'`x'_ts_`i' = cond((`es'_`modl'`x'_tp_`i'<0.10),"~"," ")
 if (`es'_`modl'`x'_tp_`i'<0.05) {
  global `es'_`modl'`x'_ts_`i' = "*"
 }

 * F-tests
 *testparm ra_`es'_*
 *scalar `es'_`modl'`x'_fp = r(p) 
 *global `es'_`modl'`x'_fs_`i' = cond((`es'_`modl'`x'_tp_`i'<0.05) & (`es'_`modl'`x'_fp<0.05),"~"," ")
 scalar `es'_`modl'`x'_fp = 0
 global `es'_`modl'`x'_fs_`i' 
 
end


capture program drop accm
program define accm
 version 7.0
 local i = `1'

 * adjusted control mean
 if "$cell" == "" | ($n_interact==1) {
  reg $y [pw=ra_weight] if esample & interact==`i' 
  scalar y_mean_`i' = _b[_cons]
  reg ra_e_`i' [pw=ra_weight] if esample & interact==`i'
  scalar e_frac_`i' = _b[_cons]
  reg ra_s_`i' [pw=ra_weight] if esample & interact==`i'
  scalar s_frac_`i' = _b[_cons]
 }
 else {
  reg $y x_i_* [pw=ra_weight] if esample, nocons
  scalar y_mean_`i' = _b[x_i_`i']
  reg ra_e x_i_* [pw=ra_weight] if esample, nocons
  scalar e_frac_`i' = _b[x_i_`i']
  reg ra_s x_i_* [pw=ra_weight] if esample, nocons
  scalar s_frac_`i' = _b[x_i_`i']
 }

 * adjusted control & complier means for interaction `i'
 scalar acm_`i' = y_mean_`i' - (e_ittx_`i' * e_frac_`i') - (s_ittx_`i' * s_frac_`i')
 scalar e_accm_`i' = acm_`i' - (e_ncdiffx_`i' * (1-e_comply_`i'))
 scalar s_accm_`i' = acm_`i' - (s_ncdiffx_`i' * (1-s_comply_`i'))
 
 * relative change for compliers for interaction `i'
 scalar e_relcx_`i' = e_totx_`i' / e_accm_`i'
 scalar s_relcx_`i' = s_totx_`i' / s_accm_`i'
end


capture program drop write_log
program define write_log
 version 7.0
 local i `1'
 local interactlbl : label interact `i'
 if "$n_interact"=="1" {
  local tf ts_`i'

  qui log using $logoneline, text append
  di %11.${d}f c_mean_`i' %11.${d}f e_ittx_`i' %7.${d}f e_ittx_tp_`i' /*
   */ %11.${d}f s_ittx_`i' %7.${d}f s_ittx_tp_`i' %15s "`interactlbl'" %5.0f `nobs' " " "$y"
  qui log close
 }
 else {
  local tf ts_`i'
 }

 if `i' == 1 {
  local agelbl     ""Ages " %3.0f ${lage} %3.0f ${uage} " 
  local rslbl      ""R-squared = " %4.3f rsquare "
  local outcomelbl ""Outcome mean = " %4.${d}f y_mean_`i' " 
  local ejointlbl  ""E-C joint p = " %4.3f e_ittx_fp "
  local sjointlbl  ""S-C joint p = " %4.3f s_ittx_fp "
 }

 qui log using $logcomma, text append
 di %6.${d}f c_mean_`i' "," _c
 di %6.${d}f e_ittx_`i' %1s "${e_ittx_`tf'}" "," %6.${d}f e_ittx_se_`i' "," %4.3f e_ittx_tp_`i' "," _c
 di %6.${d}f e_totx_`i' %1s "${e_totx_`tf'}" "," %6.${d}f e_totx_se_`i' "," %6.${d}f e_ccmorr_`i' ","  _c
 di %6.${d}f s_ittx_`i' %1s "${s_ittx_`tf'}" "," %6.${d}f s_ittx_se_`i' "," %4.3f s_ittx_tp_`i' "," _c
 di %6.${d}f s_totx_`i' %1s "${s_totx_`tf'}" "," %6.${d}f s_totx_se_`i' "," %6.${d}f s_ccmorr_`i' "," _c
 di %8.${d}f e_i21   %1s "${e_i21_ts}" "," %7.${d}f e_i21_se "," %4.3f e_i21_tp "," _c
 di %8.${d}f s_i21   %1s "${s_i21_ts}" "," %7.${d}f s_i21_se "," %4.3f s_i21_tp "," _c
 di %5.0f e_obs_`i' "," %5.0f s_obs_`i' "," %3.0f ${lage} %3.0f ${uage}  "," " `interactlbl'" "," " $y" 
 qui log close

 local c9x  = cond(e_ittx_`i'<0,9,10)
 local c9   = cond(e_itt_`i' <0,9,10)
 local c34x = cond(s_ittx_`i'<0,34,35)
 local c34  = cond(s_itt_`i' <0,34,35)
 local c17x = cond(e_totx_`i'<0,17,18)
 local c42x = cond(s_totx_`i'<0,42,43)

 qui log using $logdetail, text append
 di %4.${d}f acm_`i'  _c
 di _col(`c9x')  %4.${d}f e_ittx_`i' %1s "${e_ittx_`tf'}" _c 
 di _col(`c17x') %4.${d}f e_totx_`i' %1s "${e_totx_`tf'}" %7.${d}f e_accm_`i' _c
 di _col(`c34x') %4.${d}f s_ittx_`i' %1s "${s_ittx_`tf'}" _c
 di _col(`c42x') %4.${d}f s_totx_`i' %1s "${s_totx_`tf'}" %7.${d}f s_accm_`i' _c
 di _col(58) e_obs_`i' "  "   %-15s "`interactlbl'"  _c
 di _col(81) `agelbl'
 di _col(9)  "(" %4.${d}f e_ittx_se_`i' ")" _col(17) "(" %4.${d}f e_totx_se_`i' ")" _c
 di _col(34) "(" %4.${d}f s_ittx_se_`i' ")" _col(42) "(" %4.${d}f s_totx_se_`i' ")" _c
 di _col(58) s_obs_`i' _col(81) `rslbl'
 di _col(9)  "[" %4.3f e_ittx_tp_`i' "]"  _col(25) "{" %4.3f e_relcx_`i' "}"   _c
 di _col(34) "[" %4.3f s_ittx_tp_`i' "]"  _col(50) "{" %4.3f s_relcx_`i' "}"   _c
 di _col(81) `outcomelbl'
 di %4.${d}f c_mean_`i' _c
 di _col(`c9')  %4.${d}f e_itt_`i' %-2s "${e_itt_`tf'}" _c
 di _col(25) "<" %4.${d}f e_ccmorr_`i' ">" _c
 di _col(`c34') %4.${d}f s_itt_`i' %-2s "${s_itt_`tf'}" _c
 di _col(50) "<" %4.${d}f s_ccmorr_`i' ">" _c
 di _col(81) `ejointlbl'
 di _col(9) "(" %4.${d}f e_itt_se_`i' ")" _col(34) "(" %4.${d}f s_itt_se_`i' ")" _c
 di _col(81) `sjointlbl' 
 di
 qui log close
end


capture program drop mk_graph
program define mk_graph
 * graphs interactions for two treatments
 version 7.0
 if "${graph}" == "graph" {
  quietly {
   local graphname  ${logdir}${y}${subg}
   * variables for graphing results
   capture drop gr_x gr_e* gr_s* nn
   capture drop label gr_x
   gen gr_x=. 
   gen gr_eitt=.
   gen gr_ehi=.
   gen gr_elo=.
   gen gr_sitt=.
   gen gr_shi=.
   gen gr_slo=.
   gen nn=_n   
   local d 0.13 /* d = horizontal gap between  ex and sx results on the graph */

   local i = 1
   while `i' <= $n_interact {
    replace gr_x = `i'     if nn == (`i')*3
    replace gr_x = `i'-`d' if nn == (`i')*3-1
    replace gr_x = `i'+`d' if nn == (`i')*3+1
    replace gr_eitt = e_ittx_`i'    if gr_x == float(`i'-`d')
    replace gr_ehi  = e_ittx_hi_`i' if gr_x == float(`i'-`d')
    replace gr_elo  = e_ittx_lo_`i' if gr_x == float(`i'-`d')
    replace gr_sitt = s_ittx_`i'    if gr_x == float(`i'+`d')
    replace gr_shi  = s_ittx_hi_`i' if gr_x == float(`i'+`d')
    replace gr_slo  = s_ittx_lo_`i' if gr_x == float(`i'+`d')

    local labelgx : label interact `i'
    label define gr_x `i' "`labelgx'", modify

    local i = `i' + 1
   }
  }
  sort svy_age_imp
  label variable gr_eitt "E-C"
  label variable gr_sitt "S-C"
  label values   gr_x gr_x
  graph gr_eitt gr_ehi gr_elo gr_sitt gr_shi gr_slo gr_x, c(l[_]IIl[.]II) sort s(xiioii) /*
    */  pen(222333) psize(50) yline(0) ylabel b2(" ") xlabel(1(1)${n_interact})  /*
    */  ti("$y") saving(`graphname',replace)
  translate `graphname'.gph `graphname'.eps, replace logo(off) xsize(9) ysize(6)
 }
end


capture program drop modl_est
program define modl_est
 version 7.0
 quietly {
  capture drop esample
  local elist $y ra_e_* ra_s_* x_* 
  mark esample if include
  markout esample `elist'
  replace esample = 0 if ra_weight==0

  * Compliance rate
  regress svy_cmove ra_e_* ra_s_* [pw=ra_weight] if esample, cluster($cluster_id)
  capture drop ra_ec_* ra_sc_*
  forvalues i = 1/$n_interact {
   foreach es in e s {
    scalar `es'_comply_`i' = _b[ra_`es'_`i']
   }
  }

  foreach es in e s {
   if "`es'"=="e" {
    local esample esample & ra_group!=2    
   }
   else {
    local esample esample & ra_group!=1
   }
   * ITT Regression for interactions 
   regress $y ra_`es'_* x_* [pw=ra_weight] if `esample', cluster($cluster_id)
   scalar rsquare = e(r2)
   scalar df_mc= e(N_clust)-1
   scalar df_r = e(df_r)
   scalar df_k = e(df_m)

   if $n_interact==2 {
    lincom ra_`es'_2-ra_`es'_1 
    scalar `es'_i21    = `r(estimate)' 
    scalar `es'_i21_se = `r(se)'
    scalar `es'_i21_t  = `es'_i21/`es'_i21_se
    scalar `es'_i21_tp = ttail(df_r,abs(`es'_i21_t))*2
    global `es'_i21_ts = cond((`es'_i21_tp<0.10),"~"," ")
    global `es'_i21_ts = cond((`es'_i21_tp<0.05),"*","${`es'_i21_ts}")
   }
   else {
    scalar `es'_i21    = 0
    scalar `es'_i21_se = 0
    scalar `es'_i21_t  = 0
    scalar `es'_i21_tp = 0
    global `es'_i21_ts = ""
    global `es'_i21_ts = ""
   }

   if "$cell"=="" {
    sum interact [aw=ra_weight] if `esample' 
   }
   else {
    sum interact [fw=z_cell_count] if `esample' 
   }
   scalar df_nc=r(N) - 1

   forvalues i = 1/$n_interact {
    if "$cell" == "" {
     sum interact [aw=ra_weight] if `esample' & interact==`i'
     scalar `es'_obs_`i' = r(N)
    }
    else {
     if ($n_interact==1) {
      sum interact [fw=z_cell_count] if `esample' 
      scalar `es'_obs_`i' = r(N)
     }
     else {
      sum x_i_`i' [fw=z_cell_count] if `esample'
      scalar `es'_obs_`i' = r(N) * r(mean)
     }
    }
    store_est itt `i' x `es'
   }

   * Control & control complier means
   capture drop ra_`es'c* 
   forvalues i = 1/$n_interact {
    gen ra_`es'c0_`i' = ra_`es'_`i' * (1-svy_cmove)
    gen ra_`es'c1_`i' = ra_`es'_`i' * (svy_cmove)
   }

   * TOT from 2SLS
   ivreg $y (ra_`es'c1_* = ra_`es'_*) x_* [pw=ra_weight] if `esample', cluster($cluster_id)

   forvalues i = 1/$n_interact {
    store_est tot `i' x `es'
   }
  }

  reg $y ra_ec* ra_sc* [pw=ra_weight] if esample & ra_group!=3, nocons
  forvalues i = 1/$n_interact {
   scalar e_ccmorr_`i' = _b[ra_ec1_`i'] - e_totx_`i'
   scalar s_ccmorr_`i' = _b[ra_sc1_`i'] - s_totx_`i'
  }
  * reg $y ra_ec* ra_sc* x_* [pw=ra_weight] if `esample' 
  forvalues i = 1/$n_interact {
  * scalar e_ncdiffx_`i' = _b[ra_ec0_`i'] / e_comply_`i'
  * scalar s_ncdiffx_`i' = _b[ra_sc0_`i'] / s_comply_`i'
   scalar e_ncdiffx_`i' = 0
   scalar s_ncdiffx_`i' = 0
  }
  forvalues i = 1/$n_interact {
   accm `i'
  }

  * Simple ITT for interactions
  regress $y ra_e_* ra_s_* x_i* [pw=ra_weight] if `esample', cluster($cluster_id) nocons
  scalar df_k = e(df_m)
  forvalues i = 1/$n_interact {
   foreach es in e s {
    store_est itt `i' nox `es'
   }
   scalar c_mean_`i' = _b[x_i_`i']
  }
 }
 
 qui log using $logdetail, text append
 di %-1s "$ylbl"
 qui log close
 forvalues i = 1/$n_interact {
  write_log `i'
 }

 mk_graph

end


capture program drop interact
program define interact
 version 7.0
 * creates indicator variable include defining the estimation sample
 version 7.0
 syntax [varlist(default=none)] [, all min_n(integer 100) ages(string) ages2(string) graph cell ]
 global graph `graph'
 global cell  `cell'

 if "$cell" =="" {
  global cluster_id famid
 }
 else {
  local min_n = 1
  global cluster_id z_cell_id
 }

 * loop for up to two presentation ages
 if "`ages'"!="" {
  local maxpaloop = 1 + cond("`ages2'"=="",0,1)
 }
 else {
  local maxpaloop = cond("$presentationages1"=="",0,1) + cond("$presentationages2"=="",0,1)
 }
 local paloop = 1
 while `paloop' <= `maxpaloop' {
  if "`varlist'" =="" {
   local ilist "${interactions`paloop'}"
  }
  else {
   local ilist "`varlist'"
  }
  local numvars : word count `ilist'

  if `paloop'==1 & "`ages'" == ""  {
   local ages "${presentationages1}"
  }

  if `paloop'==2 {
   if "`ages2'" != ""  {
    local ages "`ages2'"
   }
   else {
    local ages "${presentationages2}"
   }
  }

  * loop for `all' and for interaction varlist if specified
  local maxalloop = (`numvars'>0) + cond("`all'"=="",0,1)
  local alloop = 1
  while `alloop' <= `maxalloop' {
   if !(lower("`ages'") == "none" | lower("`ages'") == "") {
    if real(substr("`ages'",2,1))==. {
     global lage = substr("`ages'",1,1)
     global uage = substr("`ages'",3,2)
    }
    else if inrange(real(substr("`ages'",1,3)),100,999) {
     global lage = substr("`ages'",1,3)
     global uage = substr("`ages'",5,7)
    }
    else {
     global lage = substr("`ages'",1,2)
     global uage = substr("`ages'",4,2)
    }
    quietly {
     capture drop include
     gen include = inrange(svy_age_imp,${lage},${uage}) & $y!=.

     * defines interaction categories
     capture drop interact
     if `numvars'==0 & "`all'"!="" {
      gen interact = 1
      label define interact 1 "All", modify
      label values interact interact
     }
     else if `numvars'>0 {
      if "$cell"!="" & `numvars'>1 {
       di "Only one subgroup variable allowed with cell data"
       error
      }
      capture drop istr
      gen str30 istr = ""
      global subg
      * loop for each var on varlist 
      forvalues i = 1/`numvars' {
       tokenize `ilist'
       local vari ``i''      
       global subg ${subg}_`vari'
       local typevar : type `vari' 
       tempvar istri nn1 nn2 ifmatch lenstr
       if substr("`typevar'",1,3) == "str" {
        gen str5 `istri' = substr(`vari' + "    ",1,4)
       }
       else {
        local valbl : value label `vari'
        if "`valbl'"!="" {
         decode `vari', gen(`istri')
        }
        else {
         gen str4 `istri' = string(`vari',"%02.0f")
        }
        replace `istri' = substr(`istri' + "    ",1,4)
       }
       qbys `vari':gen `nn1' = _N
       qbys `istri':gen `nn2' = _N
       gen `ifmatch' = `nn1'==`nn2'
       sum `ifmatch'
       if r(min)!=1 {
        di "First four characters of string label must uniquely identify group"
        error
       }
       gen `lenstr' = length(trim(`istri'))
       sum `lenstr'
       replace `istri' = substr(`istri',1,min(r(max),4))
       replace istr = istr + `istri' + " "
      }
      qbys include istr: replace istr = "" if _N < `min_n'
      capture label drop interact
      encode istr if include==1, gen(interact)
      if "`all'"!="" & `alloop'==1 {
       replace interact = 1 if interact !=.
       label define interact 1 "Allsubg", modify
      }
      replace include = 0 if interact==.
     }
     sum interact
     global n_interact = r(max)
    
     * creates interactions with treatment indicators
     capture drop ra_e_* ra_s_* x_i*
     if "$cell"=="" | ($n_interact==1) {
      forvalues i = 1/$n_interact {
       gen x_i_`i' = interact==`i'
       gen ra_e_`i' = (ra_group==1) * (interact==`i')
       gen ra_s_`i' = (ra_group==2) * (interact==`i')
      }
     }
     else {
      capture drop ra_e ra_s
      gen ra_e = ra_group==1
      gen ra_s = ra_group==2
      forvalues i = 1/$n_interact {
       gen x_i_`i' = `vari'_`i'
       gen ra_e_`i' = (ra_group==1) * `vari'_`i'
       gen ra_s_`i' = (ra_group==2) * `vari'_`i'
      }
     }
    }

    * estimate models if there are included observations
    qui sum interact
    if r(max)>0 & r(max)!=. {
     modl_est
    }
   }
   local alloop = `alloop' + 1
  }
  local paloop = `paloop' + 1
 }
end


capture program drop show
program define show
 version 7.0

 global y `1'
 capture confirm variable $y
 if _rc==0 {
  sum $y, meanonly
  if r(mean)!=. { 
   global ylbl : variable label $y
   capture drop ra_weight
   gen ra_weight=`2' 
   global d `3'  /* number of decimal places; default is 3 */
   if "$d"=="" {
    global d 3
   }

   global interactions1     `4'
   global interactions2     `5'
   global presentationages1 `6'
   global presentationages2 `7'

   setup_subgroups
  }
 }

end


capture program drop setup_logs
program define setup_logs
 * opens logs and creates headers
 version 7.0
 capture log close

 quietly log using $logoneline, replace text
 di %11s "C" %11s "E-C" %7s "p-val" %11s "S8-C" %7s "p-val"  /*
   */ %15s "subgroup" %5s "#obs" %-10s "  variable"
 qui log close

 quietly log using $logcomma, replace text
 di %7s "CM,ExITT,ExITTse,ExITTpv,ExTOT,ExTOTse,ExCCM," _c
 di "SxITT,SxITTse,SxITTpv,SxTOT,SxTOTse,SxCCM," _c
 di "ExITTdif,ExITTsedif,ExITTpvdif,SxITTdif,SxITTsedif,SxITTpvdif," _c
 di %6s "ECobs,SCobs,Age,group," %-17s "outcm" 
 qui log close

 quietly log using $logdetail, replace text
*** 4/2/04 added in logname, date and global restriction at top ***
 di "$logdetail ($S_DATE)-" `" [$restrict]"'
 di 
 di "Notes:"
 di "Regression-adjusted estimates in row 1"
 di "Unadjusted mean differences   in row 4"
 di "*  -> t-test w/p-value < .05"
 di "~  -> F-test w/p-value < .05"
 di "() -> standard errors"
 di "[] -> p-value from t-test
 di "{} -> relative change for compliers; TOT/CCM"
 di "<> -> unadjusted treatment complier mean - regression-adjusted TOT"
 di
 di %7s "ACM" %8s  " ExITT " %8s " ExTOT " %7s " ExCCM" _c
 di           %10s "S8ITT " %8s "S8TOT " %7s "S8CCM" _c
 di %7s "obs "  %-15s " group" %8s "other"
 qui log close
end


capture program drop setup_data
program define setup_data
 * loads data into memory
 version 7.0
 clear
 use $derived_vars $restrict
* qui for var x_c*: replace X = 0 if X==.
 capture gen z_cell_count=1

 label define rg 1 "Exp " 2 "Sec8" 3 "Cont"
 label values ra_group rg
 gen blranqtr=year(ra_date)*10+quarter(ra_date) - 19000

end


capture program drop setup_vars
program define setup_vars
 * creates text file with list of variables and attributes
 version 7.0
 insheet using $spreadsheet, names
 gen str8 show = "show"
 gen str30 lname = lower(name)
 sort presentationorder name
 drop if trim(lname)==""
 replace presentationages1 = `"""' + presentationages1 + `"""'
 replace presentationages2 = `"""' + presentationages2 + `"""'
 replace interactions1 = `"""' + lower(interactions1) + `"""'
 replace interactions2 = `"""' + lower(interactions2) + `"""'

 * for testing two variables
 * keep if inrange(presentationorder,13,21)

 outfile show lname weight decimals interactions1 interactions2 /*
  */ presentationages1 presentationages2 using $showfile, noquote replace wide
end


capture program drop derived_anal
program define derived_anal
 * main program
 version 7.0
 clear
 set more 1
 set memory 300m
 set matsize 400
 set linesize 255

 syntax , saving(string) [SHOWProgram]

 * setup filenames
 global showfile   showlist.do
 global logname    ${logdir}`saving'
 global logoneline ${logname}_oneline
 global logcomma   ${logname}_comma
 global logdetail  ${logname}_detail


 if "`showprogram'"=="" {
  setup_vars
 }
 setup_data
 setup_logs

 setup_newvars

 if "`showprogram'"!="" {
  showlist
 }
 else {
  do showlist
 }

 /*
 showlist    calls show for each variable on list
 show        calls subgroups defined by domain setup
 subgroups   calls interact for subgroups
 interact    creates categorical variable for interactions
              calls modl_est for included observations
 modl_est    estimates regression models 
              calls store_est, accm, write_log, mk_graph
 store_est   stores estimates as scalars and globals
 accm        calculates adjusted control complier means
 write_log   writes output to text files
 mk_graph    graphs effects for each interaction
 */
end


