* creates 15 point 2SLS double residual regression graphs

clear 
set more 1
set memory 400m
set matsize 400

global sdat ema
global p mm_c9000t_perpov_avg

global loopcount = 0
foreach ay in y y a {
 global loopcount = $loopcount + 1
 if "`ay'"=="y" {
  if $loopcount==1 {
   use $sdat if svy_sample=="CH" & svy_gender=="F",clear
  } 
  if $loopcount==2 {
   use $sdat if svy_sample=="CH" & svy_gender=="M",clear
  } 
  global smlist o m
 }

 if "`ay'"=="a" {
  use $sdat if svy_sample=="AD",clear
  global smlist m 
 }

 capture drop ra_z_*
 forvalues i = 1/5 {
  gen ra_z_1`i' = (ra_group==1)*(ra_site==`i')
  gen ra_z_2`i' = (ra_group==2)*(ra_site==`i')
 }

 tempfile usefile
 save `usefile'

 foreach sm in $smlist {
  global y sm_`ay'`sm'
  use `usefile',clear
 
  local title
  if "`ay'"=="y" {
   if $loopcount==1 {
    local title  Female Youth
    local g _f
   }
   if $loopcount==2 {
    local title  Male Youth
    local g _m
   }
  }
  if "`ay'"=="a" {
   local title  Adults
   local g
  }
  
  if "`sm'"=="o" {
   local title = "`title'" +" Overall"
  }
  if "`sm'"=="p" {
   local title = "`title'" +" Physical Health"
  }
  if "`sm'"=="m" {
   local title = "`title'" +" Mental Health"
  }
  if "`sm'"=="r" {
   local title = "`title'" +" Risky Behavior"
  }
  if "`sm'"=="e" & "`ay'"=="a" {
   local title = "`title'" +" Economic SS"
  }
  if "`sm'"=="e" & "`ay'"=="y" {
   local title = "`title'" +" Education"
  }
  
  quietly {
   capture drop include
   gen include = ($y!=. & $p!=.)
  
   capture drop xx_*
   foreach v of varlist x_site* {
    gen x`v'=`v'
   }
   tempvar y p c
   tempvar yh ph 
   gen `y' = $y
   gen `p' = $p
  }
 
  reg `y' ra_z_* xx_*  [pw=wt_`ay'] if include==1, cluster(famid)
  predict `yh'
  reg `p' ra_z_* xx_*  [pw=wt_`ay'] if include==1, cluster(famid)
  predict `ph'
  
  capture drop yres pres yhat
  reg `yh' xx_* [pw=wt_`ay'] if include==1, cluster(famid)
  predict yres, resid
  reg `ph' xx_* [pw=wt_`ay'] if include==1, cluster(famid)
  predict pres, resid
  reg yres pres [pw=wt_`ay'] if include==1, cluster(famid)
  predict yhat

  capture drop yresp 
  reg `yh' `ph' xx_* [pw=wt_`ay'] if include==1, cluster(famid)
  predict yresp, resid

  capture drop yp pp numobs
  sort ra_group ra_site include
  by ra_group ra_site include: gen yp = yres if _n==1 & include==1
  by ra_group ra_site include: gen pp = pres if _n==1 & include==1
  by ra_group ra_site include: gen numobs = _N if include==1
  
  capture drop blank sglab
  gen str1 blank = ""
  gen sglab = ""
  replace sglab = "C " if ra_group==3
  replace sglab = "S " if ra_group==2
  replace sglab = "E " if ra_group==1
  replace sglab = sglab + "Bal" if ra_site==1
  replace sglab = sglab + "Bos" if ra_site==2
  replace sglab = sglab + "Chi" if ra_site==3
  replace sglab = sglab + "LA" if ra_site==4
  replace sglab = sglab + "NY" if ra_site==5
  
  label var yhat "2SLS line" 
  label var yp "15 points"
  
  local fname outputs/2sls`ay'`sm'`g'
  keep if yp!=.
  save `fname',replace
 }
}


*** Scatterplots

local hi 3
local wi 4.5
local title

local f "outputs/2slsyo_f"
use `f',clear
drop _*
local yl "-.16 -.12 -.08 -.04 0 .04 .08 .12 .16"
local xl "-.12 -.08 -.04 0 .04 .08 .12"
local yl "-.18 -.12 -.06 0 .06 .12 .18"
local xl "-.09 -.06 -.03 0 .03 .06 .09 .12"

generate mposition=3
replace mposition=9 if sglab=="E Chi"
replace mposition=9 if sglab=="S Chi"
replace mposition=6 if sglab=="E NY"
replace mposition=9 if sglab=="E LA"
replace mposition=12 if sglab=="C Bos"

gen p0 = .03
gen y18 = .17
replace y18 = -.19 in 1

scatter yp pp [aw=numobs], ylabel(`yl') xlabel(`xl') legend(off) msymbol(O) msize(*.5) mcolor(black) || scatter yhat yp pp [aw=numobs], ytitle("Outcome relative to site overall mean") xtitle("Poverty rate relative to site overall mean") c(l i)  legend(off) mlabvposition(mposition) mlabcolor(black black) msymbol(i i) mlabel(blank sglab) title("`title'") graphregion(fcolor(white) lcolor(white) ) ysize(`hi') xsize(`wi') clwidth(medium medium) clcolor(black black) mcolor(black black)  || scatter y18 p0 , clcolor(white white) mcolor(white white) 

graph export outputs/fig2c.eps,replace

local f "outputs/2slsyo_m"
use `f',clear
drop _*
local yl "-.18 -.12 -.06 0 .06 .12 .18"
local xl "-.09 -.06 -.03 0 .03 .06 .09 .12"

generate mposition=3
replace mposition=6  if sglab=="S Bal"
replace mposition=9  if sglab=="E NY"
replace mposition=9  if sglab=="E Bos"
replace mposition=9 if sglab=="C Bos"
replace mposition=9 if sglab=="C Bal"

gen p0 = .03
gen y18 = .17
replace y18 = -.19 in 1

scatter yp pp [aw=numobs], ylabel(`yl') xlabel(`xl') legend(off) msymbol(O) msize(*.5) mcolor(black) || scatter yhat yp pp [aw=numobs], ytitle("Outcome relative to site overall mean") xtitle("Poverty rate relative to site overall mean") c(l i)  legend(off) mlabvposition(mposition) mlabcolor(black black) msymbol(i i) mlabel(blank sglab) title("`title'") graphregion(fcolor(white) lcolor(white) ) ysize(`hi') xsize(`wi') clwidth(medium medium) clcolor(black black) mcolor(black black)  || scatter y18 p0 , clcolor(white white) mcolor(white white) 

graph export outputs/fig2d.eps,replace

local f "outputs/2slsym_f"
use `f',clear
drop _*
local yl "-.18 -.12 -.06 0 .06 .12 .18"
local xl "-.09 -.06 -.03 0 .03 .06 .09 .12"

generate mposition=3
replace mposition=5  if sglab=="S LA"
replace mposition=6  if sglab=="C NY"
replace mposition=9  if sglab=="S NY"
replace mposition=9  if sglab=="E Bal"
replace mposition=9  if sglab=="C Bal"
replace mposition=11  if sglab=="E Chi"
replace mposition=7  if sglab=="S Chi"
replace mposition=12 if sglab=="E Bos"

gen p0 = .03
gen y18 = .17
replace y18 = -.19 in 1

scatter yp pp [aw=numobs], ylabel(`yl') xlabel(`xl') legend(off) msymbol(O) msize(*.5) mcolor(black) || scatter yhat yp pp [aw=numobs], ytitle("Outcome relative to site overall mean") xtitle("Poverty rate relative to site overall mean") c(l i)  legend(off) mlabvposition(mposition) mlabcolor(black black) msymbol(i i) mlabel(blank sglab) title("`title'") graphregion(fcolor(white) lcolor(white) ) ysize(`hi') xsize(`wi') clwidth(medium medium) clcolor(black black) mcolor(black black)  || scatter y18 p0 , clcolor(white white) mcolor(white white) 

graph export outputs/fig2b.eps,replace

local f "outputs/2slsam"
use `f',clear
drop _*
local yl "-.18 -.12 -.06 0 .06 .12 .18"
local xl "-.09 -.06 -.03 0 .03 .06 .09 .12"

generate mposition=3
replace mposition=9  if sglab=="E Bal"
replace mposition=12 if sglab=="S Chi"
replace mposition=9  if sglab=="E LA"
replace mposition=9  if sglab=="E NY"
replace mposition=9  if sglab=="S Bos"
replace mposition=12 if sglab=="C Bos"

gen p0 = .03
gen y18 = .17
replace y18 = -.19 in 1

scatter yp pp [aw=numobs], ylabel(`yl') xlabel(`xl') legend(off) msymbol(O) msize(*.5) mcolor(black) || scatter yhat yp pp [aw=numobs], ytitle("Outcome relative to site overall mean") xtitle("Poverty rate relative to site overall mean") c(l i)  legend(off) mlabvposition(mposition) mlabcolor(black black) msymbol(i i) mlabel(blank sglab) title("`title'") graphregion(fcolor(white) lcolor(white) ) ysize(`hi') xsize(`wi') clwidth(medium medium) clcolor(black black) mcolor(black black)  || scatter y18 p0 , clcolor(white white) mcolor(white white) 

graph export outputs/fig2a.eps,replace


/*
Notes.  The line passes through the origin with the slope from 2SLS regression of 
the outcome on poverty rate and site indicators, 
using site-by-treatment interactions as instrumental variables.

The points are from a partial regression leverage plot, or added variable plot,
of the group outcome means on the group poverty rate means, conditional on site main effects.
The points are the 15 site-by-group means implicitly used to estimate the 2SLS slope.
Since there are site main effects in the regression, the 15 points are normalized
so that the weighted mean of the three groups for each site is zero for
both the outcome and for the endogenous poverty rate variable.
The size of each point is proportional to the sample size of that group,
and correspondingly to the weight each point receives in the 2SLS regression.
*/
  

** Compare to ivreg

use $sdat,clear
 capture drop ra_z_*
 forvalues i = 1/5 {
  gen ra_z_1`i' = (ra_group==1)*(ra_site==`i')
  gen ra_z_2`i' = (ra_group==2)*(ra_site==`i')
 }

ivreg sm_am ($p = ra_z*) x_site* [pw=wt_a], cluster(famid)
ivreg sm_ym ($p = ra_z*) x_site* [pw=wt_y] if svy_gender=="F", cluster(famid)
ivreg sm_yo ($p = ra_z*) x_site* [pw=wt_y] if svy_gender=="F", cluster(famid)
ivreg sm_yo ($p = ra_z*) x_site* [pw=wt_y] if svy_gender=="M", cluster(famid)




