clear
set memory 400m
set more 1
set linesize 250

global restrict svy_sample=="AD" & inlist(svy_final_disp,"1T","1F","16")
global wgtvar wt_totsvy
global demog "x_ad_male x_site_balt x_site_bos x_site_chi x_site_la z_site_ny x_ad_race_black x_ad_race_other x_ad_ethn_hisp x_ad_nevmarr x_ad_parentu18" 
global work_ed "x_ad_working x_hh_afdc x_ad_edinsch z_ad_edgradhs z_ad_edged "
global hhld "x_hh_car x_hh_disabl x_hh_victim x_hh_noteens x_hh_size2 x_hh_size3 x_hh_size4"
global hood "x_hood_5y x_hous_mov3tm x_hood_verydissat x_hood_safenit x_hood_chat x_hood_nbrkid x_hood_nofamily x_hood_nofriend" 
global move "x_hous_fndapt x_hous_movdrgs x_hous_movschl x_hous_sec8bef" 

use ema,clear
drop x_c* 
gen x_age = (2001-year(svy_dob_i))/100
gen z_ad_edged = x_ad_edged if x_ad_edgradhs_miss ~= 1
gen z_ad_edgradhs = x_ad_edgradhs if x_ad_edgradhs_miss ~= 1
gen z_site_ny = (ra_site == 5)
gen z_age_2001 = (mdy(12,31,2001) - svy_dob_imp)/365.25

capture program drop createmeans
program define createmeans
 di "starting createmeans"
 di "$usevar"
 qui sum $usevar [aw=$wgtvar] if $restrict
 scalar mean = r(mean)
 qui sum $usevar [aw=$wgtvar] if ra_group==1 & $restrict
 scalar m_1 = r(mean)
 qui sum $usevar [aw=$wgtvar] if ra_group==2 & $restrict
 scalar m_2 = r(mean)
 qui sum $usevar [aw=$wgtvar] if ra_group==3 & $restrict
 scalar m_3 = r(mean)

 qui sum $usevar [aw=$wgtvar] if ra_group==1 & svy_cmove==0 & $restrict
 scalar m_1n = r(mean)
 qui sum $usevar [aw=$wgtvar] if ra_group==1 & svy_cmove==1 & $restrict
 scalar m_1c = r(mean)
 qui sum $usevar [aw=$wgtvar] if ra_group==2 & svy_cmove==0 & $restrict
 scalar m_2n = r(mean)
 qui sum $usevar [aw=$wgtvar] if ra_group==2 & svy_cmove==1 & $restrict
 scalar m_2c = r(mean)

 reg $usevar svy_cmove [pw=$wgtvar] if ra_group==1 & $restrict
 scalar m_1d = _b[svy_cmove]
 global sig1 = cond((ttail(e(df_r),abs(_b[svy_cmove]/_se[svy_cmove]))*2<.05),"*"," ")

 reg $usevar svy_cmove [pw=$wgtvar] if ra_group==2  & $restrict
 scalar m_2d = _b[svy_cmove]
 global sig2 = cond((ttail(e(df_r),abs(_b[svy_cmove]/_se[svy_cmove]))*2<.05),"*"," ")

 reg $usevar ra_grp_exp [pw=$wgtvar] if ra_group!=2  & $restrict
 scalar m_13 = _b[ra_grp_exp]
 global sig13 = cond((ttail(e(df_r),abs(_b[ra_grp_exp]/_se[ra_grp_exp]))*2<.05),"*"," ")

 reg $usevar ra_grp_s8  [pw=$wgtvar] if ra_group!=1  & $restrict
 scalar m_23 = _b[ra_grp_s8]
 global sig23 = cond((ttail(e(df_r),abs(_b[ra_grp_s8]/_se[ra_grp_s8]))*2<.05),"*"," ")
end

forvalues i= 1/1 {
 qui log using outputs/table_a1, text replace
 di "Var, Overall, Cmean, Emean, Ecompliers, Enoncom,Ecndiff, Smean, Scompliers, Snoncom, Scndiff" 
 qui log off
}

***** Show Mean Age with One Decimal Place *****
foreach v of varlist z_age_2001 {
 global usevar `v'
 createmeans
 qui log on
 di "$usevar," %4.1f mean "," %4.1f m_3 "," %4.1f m_1 "$sig13," %4.1f m_1c "," %4.1f m_1n ","  %4.1f m_1d "$sig1," %4.1f m_2 "$sig23," %4.1f m_2c "," %4.1f m_2n "," %4.1f m_2d "$sig2"
 qui log off
}

***** Show Means for Other Baseline Characteristics *****
foreach v of varlist $demog $work_ed $hhld $hood $move {
 global usevar `v'
 createmeans
 qui log on
 di "$usevar," %4.2f mean "," %4.2f m_3 "," %4.2f m_1 "$sig13," %4.2f m_1c "," %4.2f m_1n ","  %4.2f m_1d "$sig1," %4.2f m_2 "$sig23," %4.2f m_2c "," %4.2f m_2n "," %4.2f m_2d "$sig2"
 qui log off
}

**** Create Ns for Last Row of Table 1 ****
qui sum ra_site if $restrict
scalar num = r(N)
qui sum ra_site if ra_group==1 & $restrict
scalar n_1 = r(N)
qui sum ra_site if ra_group==2 & $restrict
scalar n_2 = r(N)
qui sum ra_site if ra_group==3 & $restrict
scalar n_3 = r(N)
qui sum ra_site if ra_group==1 & svy_cmove==0  & $restrict
scalar n_1n = r(N)
qui sum ra_site if ra_group==1 & svy_cmove==1 & $restrict
scalar n_1c = r(N)
qui sum ra_site if ra_group==2 & svy_cmove==0 & $restrict
scalar n_2n = r(N)
qui sum ra_site if ra_group==2 & svy_cmove==1 & $restrict
scalar n_2c = r(N)
forvalues i = 1/1 {
 qui log on
 di "N," %4.0f num "," %4.0f n_3 "," %4.0f n_1 "," %4.0f n_1c "," %4.0f n_1n ","  "," %4.0f n_2 "," %4.0f n_2c "," %4.0f n_2n "," 
 qui log close
}



