/*
tables_f.do

Created October 4 2002 by Jeffrey Kling
Last modified             February 16, 2004 by LS to add in adult additional outcome measures
			  April     8, 2004 by LS to add in current location employment etc.
			  April    20, 2004 by LS to add in base vs. core tracts descriptive stats

Calls derived_ema to generate analysis tables


Set file pathnames
 Four globals are required
  global spreadsheet    /* a comma delimited spreadsheet with 
                           name              variable name 
                           weight            estimation weight to be used
                           presentationorder order to be displayed (optional)
                           decimals          number of decimal places to be displayed (optional)
                                              default is 3
                           interactions1     list1 of variables to interact w/treatment (optional)
                           interactions2     list2 of variables to interact w/treatment (optional)
                           presentationages1 age range for estimation (optional)
                                              if no age range specified then no estimates 
                                              will be calculated for that variable
                           presentationages2 age range for estimation (optional) */

  global derived_vars   /* pathname of data with derived variables */
		       
  global restrict       /* drops data not needed (optional)
                           calls "use $derived_vars $restrict" */
		       
  global logdir         /* directory name for output */


Program newvars
 allows user to create new variables for subgrouping or analysis not already in $derived_vars
 also used to change or define labels for variables
 program shell may be empty or not defined


Program subgroups
 defines analysis and subgroups by calling program interact

 interact defines interactions based on the first for characters of the string
  or the value label if the variable is numeric. 
 if first four characters of the value label do not uniquely identify the numeric group
  there will be an error, and the label definition should be changed in program newvars

 interact syntax is [varlist, spreadsheet min_n(integer 100) all ages(string) ages2(string) graph]

        varlist          the list of variables to be interacted with treatment (optional)
                          default is to use interactions specified in the spreadsheet

        min_n()          the minimum allowable size of a subgroup to be estimated
                          size is sum of all observations within age range 
                           and with nonmissing value of outcome
                          default is 100

        all              indicator to results with no interactions (optional)
                          sample used for all is same as for interactions of varlist
                           so subgroups below minimum size are excluded
                          to use all observations, "interact, all"

        ages()           age range for estimation (optional)
                          takes precedence over presentationages in spreadsheet
                          ages in () must be one or two digits 
                           and separated by one non-numeric character
                           such as (5 11), (12_19), etc.

        ages2()          age range for estimation (optional)
                          only used if ages() also specified
                          creates identical table to ages(), but with specified ages2 range

        graph            indicator to produce graph of interactions
                          graph name is ${logdir}`outcome'_`interactionvars'
                          number of categories readable up to about 18


Program derived_anal
 produces estimates output into three logs

 syntax is derived_anal, saving(string) [SHOWProgram]

        saving()         name of logs: `saving'_oneline, `saving'_detail, `saving'_comma

        showprogram      indicator that program showlist should be used instead of spreadsheet
                          default is to use variable list from $spreadsheet

 _oneline is a log with one line for each variable, reporting ITT effects for all sample
 
 _detail is a log with the full set of ITT & TOT estimates, and other statistics of interest

 _comma is a comma-delimited log of ITT and TOT data suitable for import into Word tables 


Notes to Lisa:
 in Word, ${logname}_comma.log should be referenced directly as the merge data, 
  so that conversion (e.g. to Excel) does not change formats such as trailing zeros


*/

**************** SET GLOBALS AND RUN DERIVED_EMA ************************
clear
set mem 400m 
set more 1

run derived_ema

global logdir       outputs/
global derived_vars ema
global spreadsheet  NONE



*************** DEFINE PGMS for DERIVED PROGRAM *************
capture program drop setup_newvars
program define setup_newvars
 macro list derived_vars
 macro list restrict
end
capture program drop setup_subgroups
program define setup_subgroups
 interact , all
end


****** ONLY FOR SURVEYED ADULTS ********
global restrict if (inlist(svy_final_disp,"1T","1F","16") == 1 & svy_sample=="AD")



capture program drop showlist
program define showlist
***
****** Appendix Table F2: Selected Contextual Factors *******************
***
show    mm_c9000t_perpov_avg      wt_totsvy       3   ""   ""   "1_99"   "" ""
show    mm_c9000t_perpovu30_avg   wt_totsvy       3   ""   ""   "1_99"   "" ""
show    mm_c9000t_pwelf_avg       wt_totsvy       3   ""   ""   "1_99"   "" ""
show    mm_c9000t_empcivx_avg     wt_totsvy       3   ""   ""   "1_99"   "" ""
show    mm_c00t_histatus_avg      wt_totsvy       3   ""   ""   "1_99"   "" ""
show    nb_drg_sawsold_m_ad       wt_totsvy       3   ""   ""   "1_99"   "" "" 
show    mm_c9000t_pminorty_avg    wt_totsvy       3   ""   ""   "1_99"   "" ""
show    mm_c9000t_pminrtyu50_avg  wt_totsvy       3   ""   ""   "1_99"   "" ""
show    mm_move_10mi              wt_totsvy       3   ""   ""   "1_99"   "" ""
show    h_envprob_rats_ad         wt_totsvy       3   ""   ""   "1_99"   "" "" 
show    sn_net_frndgrad30_ad    wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_church_1xm_ad    wt_totsvy   3   ""   ""   "1_99"   ""
***
****** Appendix Table F3 - Results for main self-sufficiency measures ****
***
show    cc_selfsuf_ad       wt_totsvy   3   ""   ""   "1_99"   "" ""
show    w_status_emp_ad     wt_totsvy   3   ""   ""   "1_99"   "" ""
show    w_earn_2001_ad      wt_totsvy   0   ""   ""   "1_99"   "" ""
show    cc_tanf             wt_totsvy   3   ""   ""   "1_99"   "" ""
show    cc_inc_gov2001_ad   wt_totsvy   0   ""   ""   "1_99"   "" ""
***
****** Appendix Table F5 - Results for the main mental and physical health measures ****
***
show    h_ment_distk6z_ad         wt_totsvy   3   ""   ""   "1_99"   "" ""
show    h_ment_depprobadl2_y_bad   wt_totsvy   3   ""   ""   "1_99"   "" ""
show    h_ment_anxiety_y_ad       wt_totsvy   3   ""   ""   "1_99"   "" ""
show    h_ment_calm               wt_totsvy   3   ""   ""   "1_99"   "" ""
show    h_ment_sleep_78hrs        wt_totsvy   3   ""   ""   "1_99"   "" ""
show    h_hlth_fairpoor_ad        wt_totsvy   3   ""   ""   "1_99"   "" ""
show    h_adl_lim                 wt_totsvy   3   ""   ""   "1_99"   "" ""
show    h_asma_y_ad               wt_totsvy   3   ""   ""   "1_99"   "" ""
show    h_bmi2_obese_ad           wt_totsvy   3   ""   ""   "1_99"   "" ""
show    h_bp2_hi_msr              wt_totmsr   3   ""   ""   "1_99"   "" ""
***
****** Appendix Table F9 - Voucher Use, Housing, Neighborhood and Safety *******
***
*** Group: Used MTO Voucher
show    svy_cmove     wt_totsvy   3   ""   ""   "1_99"   "" "" ""
*** Group: Tract characteristics (average exposure)	
show    mm_c9000t_perpov_avg      wt_totsvy       3   ""   ""   "1_99"   ""
show    mm_c9000t_pwelf_avg       wt_totsvy       3   ""   ""   "1_99"   ""
show    mm_c9000t_empcivx_avg     wt_totsvy       3   ""   ""   "1_99"   ""
show    mm_c00t_histatus_avg    wt_totsvy       3   ""   ""   "1_99"   ""
*show    mm_c9000t_pminorty_avg   wt_totsvy       3   ""   ""   "1_99"   ""
*show    mm_c9000t_pemployf_avg   wt_totsvy       3   ""   ""   "1_99"   ""
*** Group:  neighborhood quality (average exposure)	
show    mm_nsatisflag_nomis     wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show    nb_ngbprb5_idx          wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show    h_ngbext_idxob          wt_totnobs  3   ""   ""   "1_99"   "" "" ""
*** Group:  Safety	
show    mm_safe_day_nomis       wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show    mm_safe_night_nomis     wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show    mm_victim_6mos_nomis    wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show    nb_drg_sawsold_m_ad     wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show    mm_police_noresp_nomis  wt_totsvy   3   ""   ""   "1_99"   "" "" ""
*** Group:  Housing quality
show    mm_hqual_fairpoor   wt_totsvy    3   ""   ""   "1_99"   "" "" ""  
show    h_hprob7_idx        wt_totsvy    3   ""   ""   "1_99"   "" "" "" 
show    h_env_int_idxob     wt_totnobs   3   ""   ""   "1_99"   "" "" "" 
show    h_homext_idxob      wt_totnobs   3   ""   ""   "1_99"   "" "" "" 
***
****** Appendix Table F10 - Social Netowrks *******
***
*** social networks	table
*** Group:  social networks
show    sn_net_closefrnd3_ad    wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_vstthr_1xw_ad    wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_vsthm_1xw_ad     wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_broadnet_ad      wt_totsvy   3   ""   ""   "1_99"   ""
show    w_fndjob_hood_ad        wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_nofrndhud_ad     wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_chat_1xw_ad      wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_frndgrad30_ad    wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_church_1xm_ad    wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_trust_ad         wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_discrim_ad       wt_totsvy   3   ""   ""   "1_99"   ""
***
****** Appendix Table F11 - Education, Training, Health Behv and Access *******
***
*** Group:  education and training	
show     w_educ_yrs           wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show     w_educ_hsged         wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show     w_jobtrain_sep00_ad  wt_totsvy   3   ""   ""   "1_99"   "" "" ""
*** Group: exercise and nutrition
show     h_exer_mod_fdw_ad    wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show     h_nutri_veg_fdw_ad   wt_totsvy   3   ""   ""   "1_99"   "" "" ""
*** Group: Not smoking/drinking
show     h_smoke_ad           wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show     h_alc_5plus_1xy      wt_totsvy   3   ""   ""   "1_99"   "" "" ""
*** Group: Health care access 
show     h_care_insur_ad      wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show     h_care_place2go_ad   wt_totsvy   3   ""   ""   "1_99"   "" "" ""
***
****** Appendix Table F12 - Mobility, Housing Assistance, Access to Transp, Relative Income *******
***
*** Group: Mobility
** program move and s8
show    mm_move_10mi          wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show    mm_sec8_svy           wt_totsvy   3   ""   ""   "1_99"   "" "" ""
** friends in old neighborhood 
show    sn_net_frndoldhood_ad   wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_frndoldcmvst_ad  wt_totsvy   3   ""   ""   "1_99"   ""
show    sn_net_frndoldgobck_ad  wt_totsvy   3   ""   ""   "1_99"   ""
*** Group: Transportation
show    w_transp_nearbus_ad wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show    w_transp_car_ad     wt_totsvy   3   ""   ""   "1_99"   "" "" ""
show    w_transp_license_ad wt_totsvy   3   ""   ""   "1_99"   "" "" ""
*freq too low - show    w_transp_carbus_ad  wt_totsvy   3   ""   ""   "1_99"   "" "" ""
*** Income Relative to Median Tract Income
show    mm_rel_inc2ctmed  wt_totsvy   3   ""   ""   "1_99"   "" "" ""

****** Appendix Table F14 - Employment at Zip Code Level *******
*** year after RA  - logged employment diff no cap ***
show     mm_py9495z_emplog_dif_ra1yr     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9496z_emplog_dif_ra1yr     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9497z_emplog_dif_ra1yr     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9498z_emplog_dif_ra1yr     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9499z_emplog_dif_ra1yr     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9400z_emplog_dif_ra1yr     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9401z_emplog_dif_ra1yr     wt_totsvy   3   ""   ""   "1_99"   "" ""
*** current address - logged employment diff no cap ***
show     mm_py9495z_emplog_dif_hm02     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9496z_emplog_dif_hm02     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9497z_emplog_dif_hm02     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9498z_emplog_dif_hm02     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9499z_emplog_dif_hm02     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9400z_emplog_dif_hm02     wt_totsvy   3   ""   ""   "1_99"   "" ""
show     mm_py9401z_emplog_dif_hm02     wt_totsvy   3   ""   ""   "1_99"   "" ""
end

*derived_anal, saving(table_f) showp


****************** SUBGROUP INTERACTIONS ******************************
***************** Appendix Table F6:  by Age *******************

capture program drop showlist
program define showlist
 show    cc_selfsuf_ad       wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    w_status_emp_ad     wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    w_earn_2001_ad      wt_totsvy   0   ""   ""   "1_99"   "" ""
 show    cc_tanf             wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    cc_inc_gov2001_ad   wt_totsvy   0   ""   ""   "1_99"   "" ""
 show    h_ment_distk6z_ad         wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    h_ment_depprobadl2_y_bad   wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    h_ment_anxiety_y_ad       wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    h_ment_calm               wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    h_ment_sleep_78hrs        wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    h_hlth_fairpoor_ad        wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    h_adl_lim                 wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    h_asma_y_ad               wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    h_bmi2_obese_ad           wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    h_bp2_hi_msr              wt_totmsr   3   ""   ""   "1_99"   "" ""
end

capture program drop setup_subgroups
program define setup_subgroups
 interact z_sub_ra33up, 
end
*derived_anal, saving(table_f6) showp


***************** SURVEY EMP and EARNINGS 2001 WITH AND WITHOUT BOSTON ********************************

***************** Appendix Table F7 & F8, Panel C: Employment by Age in 4 states (to compare to ADMIN) ********

capture program drop showlist
program define showlist
 show    w_emp_2001_ad       wt_totsvy   3   ""   ""   "1_99"   "" ""
 show    w_earn_2001_ad      wt_totsvy   0   ""   ""   "1_99"   "" ""
end

global restrict if inlist(svy_final_disp,"1T","1F","16") == 1 & ra_site ~= 2
*derived_anal, saving(table_f7_f8c) showp



****************************************************************************************************
**********   Appendix Table F4 
****************************************************************************************************

capture program drop showlist
program define showlist
     show     w_ui_emp_absyr_2001    wt_totcell       3        ""        ""     "1_99"         ""
     show     w_ui_emp_rel5yr_15     wt_totcell       3        ""        ""     "1_99"         ""
     show     w_ui_emp_relyr_5       wt_totcell       3        ""        ""     "1_99"         ""
     show     w_ui_wage_absyr_2001   wt_totcell       0        ""        ""     "1_99"         ""
     show     w_ui_wage_rel5yran_15  wt_totcell       0        ""        ""     "1_99"         ""
     show     w_ui_wage_relyr_5      wt_totcell       0        ""        ""     "1_99"         ""
end

global derived_vars ~/create_mto/aer_ui_5stcells
global restrict if w_ui_wage_absyr_2001!= . & svy_sample_grp == "AD"

capture program drop setup_subgroups
program define setup_subgroups
 interact , all cell
end

*derived_anal, saving(table_f4e) showprogram


capture program drop showlist
program define showlist
 show    cc_ta_yn_absyr_2001   wt_totcore   3   ""   ""   "1_99"   "" ""
 show    cc_ta_yn_relyr_5      wt_totcore   3   ""   ""   "1_99"   "" ""
 show    cc_ta_amt_absyr_2001  wt_totcore   0   ""   ""   "1_99"   "" ""
 show    cc_ta_amt_relyr_5     wt_totcore   0   ""   ""   "1_99"   "" ""
end

global derived_vars ~/create_mto/aer_tanf
global restrict if svy_sample == "AD"

capture program drop setup_subgroups
program define setup_subgroups
 interact , all
end

derived_anal, saving(table_f4t) showprogram


****************************************************************************************************
**********   Appendix Table F6 & F7
****************************************************************************************************



capture program drop showlist
program define showlist
***** Employment ******
     show                 w_ui_emp_absyr_1998   wt_totcore    3             ""       ""     "20_99"         ""
     show                 w_ui_emp_absyr_1999   wt_totcore    3             ""       ""     "20_99"         ""
     show                 w_ui_emp_absyr_2000   wt_totcore    3             ""       ""     "20_99"         ""
     show                 w_ui_emp_absyr_2001   wt_totcore    3             ""       ""     "20_99"         ""
     show                 w_ui_emp_relyr_1  wt_totcore     3             ""             ""     "20_99"         ""
     show                 w_ui_emp_relyr_2  wt_totcore     3             ""             ""     "20_99"         ""
     show                 w_ui_emp_relyr_3  wt_totcore     3             ""             ""     "20_99"         ""
     show                 w_ui_emp_relyr_4  wt_totcore     3             ""             ""     "20_99"         ""
     show                 w_ui_emp_relyr_5  wt_totcore     3             ""             ""     "20_99"         ""
     show                 w_ui_anyearn_absyr_2001 wt_totcore    3             ""      ""     "20_99"         ""

     show                 w_ui_wage_absyr_1998   wt_totcore    0             ""       ""     "20_99"         ""
     show                 w_ui_wage_absyr_1999   wt_totcore    0             ""       ""     "20_99"         ""
     show                 w_ui_wage_absyr_2000   wt_totcore    0             ""       ""     "20_99"         ""
     show                 w_ui_wage_absyr_2001   wt_totcore    0             ""       ""     "20_99"         ""
     show                 w_ui_wage_relyr_1  wt_totcore     0             ""             ""     "20_99"         ""
     show                 w_ui_wage_relyr_2  wt_totcore     0             ""             ""     "20_99"         ""
     show                 w_ui_wage_relyr_3  wt_totcore     0             ""             ""     "20_99"         ""
     show                 w_ui_wage_relyr_4  wt_totcore     0             ""             ""     "20_99"         ""
     show                 w_ui_wage_relyr_5  wt_totcore     0             ""             ""     "20_99"         ""
     show                 w_ui_wage_absyr_2001   wt_totcore    0             ""       ""     "20_99"         ""


end

global derived_vars ~/create_mto/tmp_adyt4st_20040513.dta
global restrict if w_ui_wage_absyr_2001!=. & svy_sample == "AD"

capture program drop setup_subgroups
program define setup_subgroups
 interact z_sub_ra33up, 
end

derived_anal, saving(table_f7_f8) showprogram



